@@ -1,8 +1,7 @@
 package Catalyst::DispatchType::Index;
 
-use Moose;
-extends 'Catalyst::DispatchType';
-no Moose;
+use strict;
+use base qw/Catalyst::DispatchType/;
 
 =head1 NAME
 
@@ -56,9 +55,9 @@ sub uri_for_action {
     return "/".$action->namespace;
 }
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Catalyst Contributors, see Catalyst.pm
+Sebastian Riedel, C<sri@cpan.org>
 
 =head1 COPYRIGHT
 
@@ -67,6 +66,4 @@ the same terms as Perl itself.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
-
 1;
