@@ -10,14 +10,13 @@ reference for Catalyst.
 =head1 IMPORTANT NOTE
 
 If you need to read the Catalyst Manual make sure that you have
-Catalyst::Manual installed from cpan.  To check that it is installed
-run the following command from a unix (bash) prompt:
+Catalyst::Manual installed from cpan.  To check that it is installed run the following command from a unix (bash) prompt:
 
  $ perldoc -t Catalyst::Manual::Tutorial::CatalystBasics 2>&1 >/dev/null && echo OK || echo MISSING
 
 If you see "OK" as the output, it's there, if you see "MISSING" you
-need to install the L<Catalyst::Manual> distribution
-(L<http://search.cpan.org/dist/Catalyst-Manual/>).
+need to install the
+L<Catalyst::Manual|http://search.cpan.org/search?query=Catalyst%3A%3AManual&mode=dist> distribution.
 
 =over 4
 
@@ -87,16 +86,15 @@ IRC:
 
 Mailing-Lists:
 
-    http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/catalyst
-    http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/catalyst-dev
+    http://lists.rawmode.org/mailman/listinfo/catalyst
+    http://lists.rawmode.org/mailman/listinfo/catalyst-dev
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Catalyst Contributors, see Catalyst.pm
+Sebastian Riedel, C<sri@oook.de>
+Jesse Sheidlower, C<jester@panix.com>
 
 =head1 COPYRIGHT
 
 This program is free software, you can redistribute it and/or modify it
 under the same terms as Perl itself.
-
-=cut
